=============
API Reference
=============

This section provides detailed documentation for the public classes, methods, and exceptions in the `pybticino` library, generated directly from the source code docstrings.

Core Modules
------------

.. automodule:: pybticino.auth
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pybticino.account
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pybticino.websocket
   :members:
   :undoc-members:
   :show-inheritance:

Data Models
-----------

.. automodule:: pybticino.models
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: pybticino.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
